==> fferrorhandler-2.0.3.tgz: package/test/errorTypes.test.js <==
const errorTypes = require("../errorTypes");

describe("errorTypes.js", () => {

    describe("OperationalError", () => {
        const testErrorMessage = "test message";
        const additionalErrorData = "extra data";
        const operationalError = new errorTypes.OperationalError(testErrorMessage, additionalErrorData);


        it("should be instance of OperationalError.", () => {
            expect(operationalError instanceof errorTypes.OperationalError).toBe(true);
        });

        it("should have name OperationalError.", () => {
            expect(operationalError.name).toBe("OperationalError");
        });

        it("should have property isOperational, and it should be true.", () => {
            expect(operationalError.isOperational).toBe(true);
        });

        it(`should have the message ${testErrorMessage}.`, () => {
            expect(operationalError.message).toBe(testErrorMessage);
        });

        it(`should have the data ${additionalErrorData}.`, () => {
            expect(operationalError.data).toEqual({ data: additionalErrorData, stack: operationalError.stack });
        });
    });

    describe("NonOperationalError", () => {
        const testErrorMessage = "test non operationalError";
        const additionalErrorData = "test additional data";
        const nonOperationalError = new errorTypes.NonOperationalError(testErrorMessage, additionalErrorData);

        it("should be instance of NonOperationalError", () => {
            expect(nonOperationalError instanceof errorTypes.NonOperationalError).toBe(true);

        });

        it("should have name NonOperationalError", () => {
            expect(nonOperationalError.name).toBe("NonOperationalError");
        });

        it("should have property isOperational, and it should be false.", () => {
            expect(nonOperationalError.isOperational).toBe(false);
        });

        it(`should have the message ${testErrorMessage}.`, () => {
            expect(nonOperationalError.message).toBe(testErrorMessage);
        });

        it(`should have the data ${additionalErrorData}.`, () => {
            expect(nonOperationalError.data).toEqual({ data: additionalErrorData, stack: nonOperationalError.stack });
        });
    })

    describe("HttpError", () => {
        const testErrorMessage = "test http error";
        const testStatusCode = 401;
        const additionalErrorData = "test additional data";
        const httpError = new errorTypes.HttpError(testErrorMessage, testStatusCode, additionalErrorData);

        it("should be instance of HttpError.", () => {
            expect(httpError instanceof errorTypes.HttpError).toBe(true);
        });

        it("should have name HttpError.", () => {
            expect(httpError.name).toBe("HttpError");
        });

        it("should have property isOperational, and it should be true.", () => {
            expect(httpError.isOperational).toBe(true);
        });

        it(`should have the message ${testErrorMessage}.`, () => {
            expect(httpError.message).toBe(testErrorMessage);
        });

        it(`should have the data ${additionalErrorData}.`, () => {
            expect(httpError.data).toEqual({ data: additionalErrorData, stack: httpError.stack });
        });

        it(`should have the status code ${testStatusCode}.`, () => {
            expect(httpError.statusCode).toBe(testStatusCode);
        });
    })
})

==> fferrorhandler-2.0.6.tgz: package/test/errorTypes.test.js <==
const errorTypes = require("../errorTypes");

describe("errorTypes.js", () => {

    function _makeMockShortStack(stack) {
        let callie = stack.split("\n")[1] || "";
        let caller = stack.split("\n")[2] || "";

        return { callie: callie, caller: caller };
    }

    describe("OperationalError", () => {
        const testErrorMessage = "test message";
        const additionalErrorData = "extra data";
        const operationalError = new errorTypes.OperationalError(testErrorMessage, additionalErrorData);


        it("should be instance of OperationalError.", () => {
            expect(operationalError instanceof errorTypes.OperationalError).toBe(true);
        });

        it("should have name OperationalError.", () => {
            expect(operationalError.name).toBe("OperationalError");
        });

        it("should have property isOperational, and it should be true.", () => {
            expect(operationalError.isOperational).toBe(true);
        });

        it(`should have the message ${testErrorMessage}.`, () => {
            expect(operationalError.message).toBe(testErrorMessage);
        });

        it(`should have the data ${additionalErrorData}.`, () => {
            expect(operationalError.data).toEqual(JSON.stringify({..._makeMockShortStack(operationalError.stack), data: additionalErrorData,  }));
        });
    });

    describe("NonOperationalError", () => {
        const testErrorMessage = "test non operationalError";
        const additionalErrorData = "test additional data";
        const nonOperationalError = new errorTypes.NonOperationalError(testErrorMessage, additionalErrorData);

        it("should be instance of NonOperationalError", () => {
            expect(nonOperationalError instanceof errorTypes.NonOperationalError).toBe(true);

        });

        it("should have name NonOperationalError", () => {
            expect(nonOperationalError.name).toBe("NonOperationalError");
        });

        it("should have property isOperational, and it should be false.", () => {
            expect(nonOperationalError.isOperational).toBe(false);
        });

        it(`should have the message ${testErrorMessage}.`, () => {
            expect(nonOperationalError.message).toBe(testErrorMessage);
        });

        it(`should have the data ${additionalErrorData}.`, () => {
            expect(nonOperationalError.data).toEqual(JSON.stringify({ ..._makeMockShortStack(nonOperationalError.stack), data: additionalErrorData }));
        });
    })

    describe("HttpError", () => {
        const testErrorMessage = "test http error";
        const testStatusCode = 401;
        const additionalErrorData = "test additional data";
        const httpError = new errorTypes.HttpError(testErrorMessage, testStatusCode, additionalErrorData);

        it("should be instance of HttpError.", () => {
            expect(httpError instanceof errorTypes.HttpError).toBe(true);
        });

        it("should have name HttpError.", () => {
            expect(httpError.name).toBe("HttpError");
        });

        it("should have property isOperational, and it should be true.", () => {
            expect(httpError.isOperational).toBe(true);
        });

        it(`should have the message ${testErrorMessage}.`, () => {
            expect(httpError.message).toBe(testErrorMessage);
        });

        it(`should have the data ${additionalErrorData}.`, () => {
            expect(httpError.data).toEqual(JSON.stringify({ ..._makeMockShortStack(httpError.stack), data: additionalErrorData }));
        });

        it(`should have the status code ${testStatusCode}.`, () => {
            expect(httpError.statusCode).toBe(testStatusCode);
        });
    })
})
